set more off
clear all
/* ---------------------------------------------------------------------------

PURPOSE: Create appendix tables and figures

DATE CREATED: 1/5/2018
--------------------------------------------------------------------------- */

***********************************
* SIGI 2014 vs. Fertility in 2010 *
***********************************
use ../cleandata/sigi_fertility10.dta, clear

correlate fertility10 loggdp10 sigi
eststo clear
eststo: reg fertility10 loggdp10, robust 
eststo: reg fertility10 loggdp10 sigi, robust 
lab var fertility10 "Fertility"
lab var loggdp10 "GDP per capita, PPP"
lab var sigi "SIGI" 
esttab using ../outtabs/ap_sigi_fertility10_reg.tex, label replace booktabs se r2 ///
	star(* .10 ** .05 *** .01) nonotes

twoway (scatter sigi fertility10) (lfit sigi fertility10), legend(off) graphregion(color(white)) ///
	ytitle("SIGI") xtitle("Fertility in 2010")  
graph export ../outfigs/ap_sigi_fertility10.pdf, replace


**************************
* DHS Country-Level Data *
**************************
use ../cleandata/dhs.dta,clear

*create variable for difference in fertility intentions 
*(ideal number of children for married men - ideal number of children for married women)
gen diff_ideal = idealnumchild_m_married - idealnumchild_w_married

*code polygny as 0 if missing
gen polygny_all_miss = polygny_all
replace polygny_all_miss = 0 if polygny_all==.
lab var polygny_all_miss "\% Polygny (Missing coded as 0)"


*Summary statistics table
sum diff_ideal polygny_all
sum polygny_all, d
tab survey_yr if polygny_all !=.
xtile poly_q2 = polygny_all, nq(2)

lab var idealnumchild_m_married "Ideal children for married men"
lab var idealnumchild_w_married "Ideal children for married women"
lab var diff_ideal "Difference in ideal children"
lab var polygny_all "\% Polygny"
lab var survey_yr "Survey Year"
eststo clear
estpost sum fertilityrate idealnumchild_m_married idealnumchild_w_married diff_ideal sigi_value 
eststo A
estpost sum fertilityrate idealnumchild_m_married idealnumchild_w_married diff_ideal polygny_all sigi_value  if polygny_all !=.
eststo B
estpost sum fertilityrate idealnumchild_m_married idealnumchild_w_married diff_ideal polygny_all sigi_value  if poly_q2 == 1
eststo C
estpost sum fertilityrate idealnumchild_m_married idealnumchild_w_married diff_ideal polygny_all sigi_value  if poly_q2 == 2
eststo D
esttab A B C D using ../outtabs/ap_summarystats.tex, replace  ///
	mtitle("All" "Polygny Available" "Below Median Polygny" "Above Median Polygny") ///
	cells("mean(fmt(2)) " sd(par fmt(2)) ) label booktabs nonum collabels("Mean (SD)")  ///
	gaps 


lab var lgdp "GDP per capita, PPP"
*Run regressions
lab var polygny_all "\% Polygny"
gen polygny_all20 = 1 if polygny_all >20 & polygny_all !=.
replace polygny_all20 = 0 if polygny_all <=20
lab var polygny_all20 "Polygny over 20\%"
eststo clear
eststo: reg diff_ideal polygny_all, robust
estadd ysumm
eststo: reg diff_ideal polygny_all_miss, robust
estadd ysumm
eststo: reg diff_ideal sigi_value, robust
estadd ysumm
eststo: reg diff_ideal polygny_all sigi_value, robust
estadd ysumm
eststo: reg diff_ideal polygny_all_miss sigi_value, robust
estadd ysumm
eststo: reg diff_ideal polygny_all20 sigi_value, robust
estadd ysumm
esttab using ../outtabs/ap_diffideal_polygny.tex, label replace booktabs se r2 nonotes ///
	stats(N r2 ymean, labels(Observations \(R^2\) Y-Mean)) nodepvar nomtitle star(* .10 ** .05 *** .01)
	


*same thing but with gdp
eststo clear
eststo: reg diff_ideal polygny_all lgdp, robust
estadd ysumm
eststo: reg diff_ideal polygny_all_miss lgdp, robust
estadd ysumm
eststo: reg diff_ideal sigi_value lgdp, robust
estadd ysumm
eststo: reg diff_ideal polygny_all sigi_value lgdp, robust
estadd ysumm
eststo: reg diff_ideal polygny_all_miss sigi_value lgdp, robust
estadd ysumm
eststo: reg diff_ideal polygny_all20 sigi_value lgdp, robust
estadd ysumm
esttab using ../outtabs/ap_diffideal_polygny_gdp.tex, label replace booktabs se r2 nonotes ///
	stats(N r2 ymean, labels(Observations \(R^2\) Y-Mean)) nodepvar nomtitle star(* .10 ** .05 *** .01)
	

*****************
* DHS Microdata *
*****************
use ../cleandata/dhs_microdata.dta, clear
*drop if ideal number of children for women or man is greater than 15
drop if idealnumchild_w >=15 | idealnumchild_m >=15

lab var age_w "Age"
lab var educ_w "Years of education"
lab var child_w "Total children"
lab var idealnumchild_w "Ideal number of children"

* Summary statistics for micro data
eststo clear
estpost sum age_w age_gap educ_w  educ_gap child_w idealnumchild_w diffideal polygny work_w index d1-d4  [aw=weight_w] if country == "Burkina Faso"
eststo A
estpost sum age_w age_gap educ_w  educ_gap child_w idealnumchild_w diffideal polygny work_w index d1-d4  [aw=weight_w] if country == "Burkina Faso" & age_w >=40
eststo B
estpost sum age_w age_gap educ_w  educ_gap child_w idealnumchild_w diffideal polygny work_w index d1-d4  [aw=weight_w] if country == "Burkina Faso" & age_w >=45
eststo C
estpost sum age_m educ_m child_m idealnumchild_m [aw=weight_m] if country == "Burkina Faso"
eststo D
estpost sum age_m educ_m child_m idealnumchild_m [aw=weight_m] if country == "Burkina Faso" & age_w >=40
eststo E
estpost sum age_m educ_m child_m idealnumchild_m [aw=weight_m] if country == "Burkina Faso" & age_w >=45
eststo F
esttab B E C F using ../outtabs/ap_summarystats_bf_drop15.tex,  cells("mean(fmt(2))" sd(par fmt(2)) )  ///
	nonum collabels("Mean (SD)") mtitle("Women 40+" "Men with wives 40+" "Women 45+"  "Men with wives 45+" ) replace gaps ///
	rename(age_m age_w educ_m educ_w child_m child_w idealnumchild_m idealnumchild_w) ///
	label booktabs refcat(d1 "Woman has some say in ...",nol)
	
eststo clear
estpost sum age_w age_gap educ_w educ_gap child_w idealnumchild_w diffideal polygny work_w index d1-d4  [aw=weight_w] if country == "Ethiopia"
eststo A
estpost sum age_w age_gap educ_w  educ_gap child_w idealnumchild_w diffideal polygny work_w index d1-d4  [aw=weight_w] if country == "Ethiopia" & age_w >=40
eststo B
estpost sum age_w age_gap educ_w  educ_gap child_w idealnumchild_w diffideal polygny work_w index d1-d4  [aw=weight_w] if country == "Ethiopia" & age_w >=45
eststo C
estpost sum age_m educ_m child_m idealnumchild_m [aw=weight_m] if country == "Ethiopia"
eststo D
estpost sum age_m educ_m child_m idealnumchild_m [aw=weight_m] if country == "Ethiopia" & age_w >=40
eststo E
estpost sum age_m educ_m child_m idealnumchild_m [aw=weight_m] if country == "Ethiopia" & age_w >=45
eststo F
esttab B E C F using ../outtabs/ap_summarystats_et_drop15.tex,  cells("mean(fmt(2))" sd(par fmt(2)) )  ///
	nonum collabels("Mean (SD)") mtitle("Women 40+" "Men with wives 40+" "Women 45+"  "Men with wives 45+" ) replace gaps ///
	rename(age_m age_w educ_m educ_w child_m child_w idealnumchild_m idealnumchild_w) ///
	label booktabs refcat(d1 "Woman has some say in ...",nol)


*Kernel density after dropping those with ideal number of children greater than 15
sum diffideal [aw=weight_w] if age_w>=45 & country=="Burkina Faso"
local bf = `r(mean)'
sum diffideal [aw=weight_w] if age_w>=45 & country=="Ethiopia"
local et = `r(mean)'
twoway (kdensity diffideal [aw=weight_w] if age_w>=45 & country=="Burkina Faso" , range(-10 10) bw(3) clcolor(black))  ///
	(kdensity diffideal [aw=weight_w] if age_w>=45 & country=="Ethiopia" , range(-10 10) bw(3) clcolor(black) clpattern(dash)) , ///
	xline(`bf', lcolor(black)) xline(`et', lpattern(dash) lcolor(black)) ///
	legend(order(1 "Burkina Faso" 2 "Ethiopia") rows(1)) ///
	xtitle("Difference in ideal number of children") ytitle("Density") graphregion(color(white)) 
graph export ../outfigs/ap_diffideal_dist_drop15.pdf, replace

lab var idealnumchild_w "Ideal children (woman)"
lab var d1 "Woman has say in own health care"
lab var d2 "Woman has say in large household purchases"
lab var d3 "Woman has say in visits to family or relatives"	
lab var d4 "Woman has say in what to do with money husband earns"

* Explaining difference in ideal number of children by country
foreach c in bf et{
	if "`c'"=="bf"{
		local cname = "Burkina Faso"
	}
	else if "`c'"=="et"{
		local cname = "Ethiopia"
	}
	eststo clear
	eststo: reg diffideal age_w age_gap educ_gap i.polygny [pw=weight_w] if country=="`cname'" & age_w>=40, robust cluster(hhid)
	estadd ysumm

	eststo: reg diffideal age_w age_gap educ_gap i.polygny d1-d4 [pw=weight_w] if country=="`cname'" & age_w>=40, robust cluster(hhid)
	estadd ysumm

	eststo: reg diffideal age_w age_gap educ_gap i.polygny index [pw=weight_w] if country=="`cname'" & age_w>=40, robust cluster(hhid)
	estadd ysumm

	eststo: reg diffideal age_w age_gap educ_gap i.polygny work_w [pw=weight_w] if country=="`cname'" & age_w>=40, robust cluster(hhid)
	estadd ysumm

	eststo: reg diffideal age_w age_gap educ_gap i.polygny work_w index [pw=weight_w] if country=="`cname'" & age_w>=40, robust cluster(hhid)
	estadd ysumm

	
	esttab using ../outtabs/ap_diffideal_`c'_drop15.tex, label replace se r2 ///
	booktabs noomitted drop(0.polygny) nonotes ///
	stats(N r2 ymean, labels(Observations \(R^2\) Y-Mean)) nodepvar nomtitle star(* .10 ** .05 *** .01)
}

* Explaining total number of children
lab var child_w "Total children"
foreach age in 40 45{
	replace educq_w`age' = educq_w`age' - 1
	lab var educq_w`age' "High female education"
	replace age_gapq`age' = age_gapq`age'-1
	lab var age_gapq`age' "High age gap"
	replace educ_gapq`age' = educ_gapq`age'-1
	lab var educ_gapq`age' "High education gap"
	
	foreach c in bf et{
		if "`c'"=="bf"{
			local cname = "Burkina Faso"
		}
		else if "`c'"=="et"{
			local cname = "Ethiopia"
		}

		eststo clear
		eststo: reg child_w idealnumchild_w idealnumchild_m if age_w >=`age' & country=="`cname'", robust cluster(hhid)
		estadd ysumm
		
		eststo: reg child_w c.idealnumchild_w##i.educq_w`age' c.idealnumchild_m##i.educq_w`age' if age_w >=`age' & country=="`cname'" , robust cluster(hhid)
		estadd ysumm	

		eststo: reg child_w c.idealnumchild_w##i.age_gapq`age' c.idealnumchild_m##i.age_gapq`age' if age_w >=`age' & country=="`cname'"  , robust cluster(hhid)
		estadd ysumm	

		eststo: reg child_w c.idealnumchild_w##i.educ_gapq`age' c.idealnumchild_m##i.educ_gapq`age' if age_w >=`age' & country=="`cname'"  , robust cluster(hhid)
		estadd ysumm	
		
		sum educ_w [aw=weight_w] if country=="`cname'" & age_w >=`age', d
		local educ = round(`r(p50)',2)
		
		sum age_gap [aw=weight_w] if country=="`cname'" & age_w >=`age', d
		local agegap = round(`r(p50)',2)
		
		sum educ_gap [aw=weight_w] if country=="`cname'" & age_w >=`age', d
		local educgap = round(`r(p50)',2)	
		
		esttab using ../outtabs/ap_fert_ideal`age'_`c'_drop15.tex, label replace se r2 ///
		booktabs nonotes noomitted drop(0.*) ///
		stats(N r2 ymean, labels(Observations \(R^2\) Y-Mean)) star(* .10 ** .05 *** .01)
			
	}
}
foreach age in 40 45{
	lab var indexq`age' "High female HH decision index"
	replace indexq`age' = indexq`age'-1
	foreach c in bf et{
		if "`c'"=="bf"{
			local cname = "Burkina Faso"
		}
		else if "`c'"=="et"{
			local cname = "Ethiopia"
		}

		eststo clear
		eststo: reg child_w idealnumchild_w idealnumchild_m if age_w >=`age' & country=="`cname'", robust cluster(hhid)
		estadd ysumm
		
		eststo: reg child_w c.idealnumchild_w##i.indexq`age' c.idealnumchild_m##i.indexq`age' if age_w >=`age' & country=="`cname'" , robust cluster(hhid)
		estadd ysumm	

		eststo: reg child_w c.idealnumchild_w##i.work_w c.idealnumchild_m##i.work_w if age_w >=`age' & country=="`cname'"  , robust cluster(hhid)
		estadd ysumm	

		
		sum index [aw=weight_w] if country=="`cname'" & age_w >=`age', d
		local index = round(`r(p50)',2)
		
		esttab using ../outtabs/ap_fert_ideal`age'_alt_`c'_drop15.tex, label replace se r2  ///
		booktabs nonotes noomitted drop(0.*) ///
		stats(N r2 ymean, labels(Observations \(R^2\) Y-Mean)) star(* .10 ** .05 *** .01)
			
	}
}


