set more off
clear all
/* ---------------------------------------------------------------------------

PURPOSE: Import data for analysis 

DATE CREATED: 1/5/2018
--------------------------------------------------------------------------- */

***********************************
* SIGI 2014 vs. Fertility in 2010 *
***********************************
clear
* Import total fertility in 2010
insheet using ../rawdata/sigi_fertility10/WDI_fertility.csv, names

rename CountryName country
rename yr1990 fertility90
rename yr2000 fertility00
rename yr2010 fertility10

drop countrycode
drop seriesname
drop seriescode

destring fertility*, replace force
keep country fertility10
drop if country==""
tempfile fert
save `fert', replace


* Import gdp in 2010
clear
insheet using ../rawdata/sigi_fertility10/WDI_GDPpc_current.csv, names 

rename CountryName country
rename yr1990 gdpcurrent90
rename yr2000 gdpcurrent00
rename yr2010 gdpcurrent10

drop countrycode
drop seriesname
drop seriescode

destring gdpcurrent*, replace force
keep country gdpcurrent10
gen loggdp10 = log(gdpcurrent10)
drop if country==""
tempfile gdp
save `gdp', replace


* Import sigi data
insheet using ../rawdata/sigi_fertility10/SIGI2014_mycsv.csv, delimiter(";") names clear
gen sigi=subinstr(socialinsitutionsandgenderindexs,",",".",.)

destring sigi, replace force
keep country sigi

* Merge all the datasets together
merge 1:1 country using `fert', nogen 
merge 1:1 country using `gdp', nogen 


drop if country==""

drop if country=="Caribbean small states"
drop if country=="Central Europe and the Baltics"
drop if country=="Data from database: World Development Indicators"
drop if country=="Early-demographic dividend"
drop if country=="East Asia & Pacific"
drop if country=="East Asia & Pacific (IDA & IBRD countries)"
drop if country=="East Asia & Pacific (excluding high income)"
drop if country=="Euro area"
drop if country=="Europe & Central Asia"
drop if country=="Europe & Central Asia (IDA & IBRD countries)"
drop if country=="Europe & Central Asia (excluding high income)"
drop if country=="European Union"
drop if country=="Fragile and conflict affected situations"
drop if country=="Heavily indebted poor countries (HIPC)"
drop if country=="High income"
drop if country=="IBRD only"
drop if country=="IDA & IBRD total"
drop if country=="IDA blend"
drop if country=="IDA only"
drop if country=="IDA total"
drop if country=="Last Updated: 10/30/2017"
drop if country=="Late-demographic dividend"
drop if country=="Latin America & Caribbean"
drop if country=="Latin America & Caribbean (excluding high income)"
drop if country=="Latin America & the Caribbean (IDA & IBRD countries)"
drop if country=="Least developed countries: UN classification"
drop if country=="Low & middle income"
drop if country=="Low income"
drop if country=="Lower middle income"
drop if country=="Middle East & North Africa"
drop if country=="Middle East & North Africa (IDA & IBRD countries)"
drop if country=="Middle East & North Africa (excluding high income)"
drop if country=="Middle income"
drop if country=="Not classified"
drop if country=="OECD members"
drop if country=="Other small states"
drop if country=="Pacific island small states"
drop if country=="Post-demographic dividend"
drop if country=="Pre-demographic dividend"
drop if country=="South Asia"
drop if country=="South Asia (IDA & IBRD)"
drop if country=="Sub-Saharan Africa (IDA & IBRD countries)"
drop if country=="Sub-Saharan Africa (excluding high income)"
drop if country=="Upper middle income"

save ../cleandata/sigi_fertility10.dta,replace


**************************
* DHS Country-Level Data *
**************************
clear
import delimited using ../rawdata/dhs/sigi.txt

rename sigi2014category sigi_category
rename sigivalue2014sorticon sigi_value
lab var sigi_value "SIGI"

destring sigi_value , force replace ignore("N/A")
keep country sigi_value
tempfile sigi
save `sigi', replace


*Import DHS Statcompiler Data
import excel using ../rawdata/dhs/dhs_statcompiler.xlsx, sheet("Indicator Data") cellrange(A4) firstrow clear

label var survey "Most recent DHS survey"
label var fertilityrate_15to49 "Total fertility rate 15-49"
label var idealnumchild_w_all "Mean ideal number of children for all women"
label var idealnumchild_w_married "Mean ideal number of children for currently married women"
label var idealnumchild_m_all "Mean ideal number of children for all men"
label var idealnumchild_m_married "Mean ideal number of children for currently married men"
label var idealnumchild_m_all_15to54 "Mean ideal number of children for all men 15-54(59)"
label var idealnumchild_m_married_15to54 "Mean ideal number of children for currently married men 15-54(59)"
label var married_m_all "\% Married or living in union for all men"
label var married_m_15to49 "\% Married or living in union for all men 15-49"
label var onewife_all "\% Number of wives: One wife for all men"
label var onewife_15to49 "\% Number of wives: One wife for all men 15-49"
label var polygny_all "\% Number of wives: Two or more wives for all men"
label var polygny_15to49 "\% Number of wives: Two or more wives for all men 15-49"

tempfile dhs_statcompiler
save `dhs_statcompiler', replace

*import GDP
clear
import delimited using ../rawdata/dhs/gdp.csv
drop if _n==1 | _n==2
keep v1 v5-v61
rename v1 country

local yr = 1960
forval j = 5/61{
	rename v`j' gdp_`yr'
	local yr = `yr' + 1
}
drop if _n==1

*fix some country names for merge with DHS data
replace country = "Egypt" if country == "Egypt, Arab Rep."
replace country = "Yemen" if country == "Yemen, Rep."
replace country = "Gambia" if country == "Gambia, The"
replace country = "Congo" if country == "Congo, Rep."
replace country = "Congo Democratic Republic" if country == "Congo, Dem. Rep."

*reshape the dataset so that we have gdp by year by country
reshape long gdp_, i(country) j(year)
rename gdp_ gdp

*create log gdp
gen lgdp = log(gdp)
lab var gdp "GDP per capita, PPP (2011 International $)"
lab var lgdp "Log GDP per capita, PPP (2011 International $)"

tempfile gdp
save `gdp', replace

*merge data
clear
use `sigi'

*fix some country names for merge
replace country = "Congo" if country == "Congo, Rep."
replace country = "Congo Democratic Republic" if country == "Congo, Dem. Rep."
replace country = "Vietnam" if country == "Viet Nam"
replace country = "Trinidad and Tobago" if country == "Trinidad And Tobago"
replace country = "Kyrgyz Republic" if country == "Kyrgyzstan"
replace country = "Cote d'Ivoire" if country == "Cote D'Ivoire"
merge 1:1 country using `dhs_statcompiler'
drop _merge

*create variable for survey year
gen survey_yr = word(survey,1)
replace survey_yr = substr(survey_yr,1,4) if regexm(survey, "-") 
destring survey_yr, replace

*create a year variable to merge data with the GDP data
gen year =survey_yr
merge 1:1 country year using `gdp', keep(matched master) 
drop _merge
save ../cleandata/dhs.dta,replace

*****************
* DHS Microdata *
*****************
foreach dhs in bf et {
	clear
	use ../rawdata/dhs_microdata/`dhs'_couples.dta
	egen hhid = group(v001 v002)
	egen id_w = group(v001 v002 v003)
	egen id_m = group(mv001 mv002 mv003)

	* Fix weights according to the DHS manual
	replace v005 = v005/1000000
	replace mv005 = mv005/1000000

	* check if these two weights are equal (no they are not!)
	rename v005 weight_w
	rename mv005 weight_m
	count if weight_w==weight_m

	* Check if same number of individuals as in Michele's paper
	* For BF: W 17,087 M 7,307
	/* 5188 men; 5161 women in this dataset
	* Checked and found that Michele had used the non-
	* linked couple records. was able to replicate her counts

	collapse (count) id_m [pw=weight_m] 
	collapse (count) id_f [pw=weight_w]
	*/

	* Create polygny variable: Polygyny is measured as the fraction of all women, 
	* who are married or live together with their partner (using female weight)
	* mv035 is the variable for # of wives for each man
	gen polygny = (mv035 >= 2)
	replace polygny = . if mv035 ==. 
	sum polygny [aw=weight_w]
	lab var polygny "Polygny"

	* age
	gen age_w = v012
	gen age_m = mv012

	sum age_w [aw=weight_w] // avg age of women 30 (15-49) (BF)
	sum age_m [aw=weight_m] // avg age of men 39 (15-59) (BF)
	
	lab var age_w "Age (Woman)"
	lab var age_m "Age (Man)"

	* create age gap variable
	gen age_gap = age_m - age_w
	sum age_gap [aw=weight_w] // men are 9 years older on avg (-14-41) (BF)
	lab var age_gap "Age gap"
	
	* create above/below median age gap variable
	xtile age_gapq = age_gap [aw=weight_w], nq(2)
	xtile age_gapq40 = age_gap [aw=weight_w] if age_w >=40, nq(2)
	xtile age_gapq40_nopoly = age_gap [aw=weight_w] if age_w >=40 & polygny==0, nq(2)
	xtile age_gapq45 = age_gap [aw=weight_w] if age_w >=45, nq(2)
	xtile age_gapq45_nopoly = age_gap [aw=weight_w] if age_w >=45 & polygny==0, nq(2)
	
	* education 
	gen educ_w = v133 
	gen educ_m = mv133
	
	replace educ_w = . if educ_w == 99
	replace educ_m = . if educ_m == 99

	sum educ_w [aw=weight_w] // avg years of education 1.05 for women (0-18) (BF)
	sum educ_m [aw=weight_m] // avg years of education 1.47 for men (0-18)  (BF)
	
	lab var educ_w "Years of education (woman)"
	lab var educ_m "Years of education (man)"
	
	* create above/below median education variable
	xtile educq_w = educ_w [aw=weight_w], nq(2)
	xtile educq_w40 = educ_w [aw=weight_w] if age_w>=40, nq(2)
	xtile educq_w40_nopoly = educ_w [aw=weight_w] if age_w>=40 & polygny==0, nq(2)
	xtile educq_w45 = educ_w [aw=weight_w] if age_w>=45, nq(2)
	xtile educq_w45_nopoly = educ_w [aw=weight_w] if age_w>=45 & polygny==0, nq(2)
	
	* create education gap variable
	gen educ_gap = educ_m - educ_w
	sum educ_gap [aw=weight_w] //0.4 years more education (BF)
	lab var educ_gap "Education gap"
	
	* create above/below median education gap variable
	xtile educ_gapq = educ_gap [aw=weight_w], nq(2)
	xtile educ_gapq40 = educ_gap [aw=weight_w] if age_w >=40, nq(2)
	xtile educ_gapq40_nopoly = educ_gap [aw=weight_w] if age_w >=40 & polygny==0, nq(2)
	xtile educ_gapq45 = educ_gap [aw=weight_w] if age_w >=45, nq(2)
	xtile educ_gapq45_nopoly = educ_gap [aw=weight_w] if age_w >=40 & polygny==0, nq(2)
	
	* total children
	gen child_w = v201
	gen child_m = mv201
	
	count if child_w == child_m // 2181 (unweighted) (BF)
	count if child_w > child_m  // 306 (unweighted) (BF)
	count if child_w < child_m  // 2601 (unweighted) (BF)

	sum child_w [aw=weight_w]
	sum child_m [aw=weight_m]
	
	lab var child_w "Total children (woman)"
	lab var child_m "Total children (man)"

	* ideal number of children
	gen idealnumchild_w = v613
	replace idealnumchild_w =. if v613 > 90 //replace "non numeric" response with missing & "god/allah's will" as missing also
	gen idealnumchild_m = mv613
	replace idealnumchild_m =. if mv613 > 90 // replacing 99 as missing
	
	sum idealnumchild_w [aw=weight_w]
	sum idealnumchild_m [aw=weight_m]
	
	lab var idealnumchild_w "Ideal children (woman)"
	lab var idealnumchild_m "Ideal children (man)"
	
	* difference in ideal number of children
	gen diffideal = idealnumchild_m - idealnumchild_w
	sum diffideal [aw=weight_w]
	lab var diffideal "Difference in ideal number of children"
	
	* employment (if the woman has worked in the last 12 months)
	gen work_w = v731
	gen work_m = mv731
	replace work_w = 1 if inlist(work_w, 1, 2,3)
	replace work_m = 1 if inlist(work_m, 1, 2,3)
	replace work_w = . if work_w ==9
	replace work_m = . if work_m ==9
	lab var work_w "Worked in past 12 months (woman)"
	lab var work_m "Worked in past 12 months (man)"
	
	sum work*
	
	* female decision making in the household
	gen d1 = 1 if v743a == 1 | v743a==2
	replace d1 = 0 if v743a==4 | v743a== 5 | v743a==6
	replace d1 = . if v743a==9
	lab var d1 "- own health care"
	
	gen d2 = 1 if v743b == 1 | v743b==2
	replace d2 = 0 if v743b==4 | v743b== 5 | v743b==6
	replace d2 = . if v743b==9
	lab var d2 "- large household purchases"

	gen d3 = 1 if v743d == 1 | v743d==2
	replace d3 = 0 if v743d==4 | v743d== 5 | v743d==6
	replace d3 = . if v743d==9
	lab var d3 "- visits to family or relatives"	
	
	gen d4 = 1 if v743f == 1 | v743f==2
	replace d4 = 0 if v743f==4 | v743f== 5 | v743f==6
	replace d4 = . if v743f==9
	lab var d4 "- what to do with money husband earns"
	
	egen index = rowtotal(d1 d2 d3 d4)
	lab var index "Female HH decision index"

	* create above/below median education gap variable
	* (for Ethiopia, even if the highest value is provided,
	* it is considered the 49th percentile even though the median is 4) 
	xtile indexq = index [aw=weight_w], nq(2)
	xtile indexq40 = index [aw=weight_w] if age_w >=40, nq(2)
	replace indexq40 = 2 if index==4 & age_w >=40 & "`dhs'"== "et"
	xtile indexq40_nopoly = index [aw=weight_w] if age_w >=40 & polygny==0, nq(2)
	replace indexq40_nopoly = 2 if index==4 & age_w >=40 & "`dhs'"== "et" & polygny==0
	xtile indexq45_nopoly = index [aw=weight_w] if age_w >=45 & polygny==0, nq(2)
	replace indexq45_nopoly = 2 if index==4 & age_w >=45 & "`dhs'"== "et" & polygny==0	
	xtile indexq45 = index [aw=weight_w] if age_w >=45, nq(2)
	replace indexq45 = 2 if index==4 & age_w >=45 & "`dhs'"== "et"
	
	sum d1-d4 index
	
	tempfile `dhs'
	save ``dhs'', replace
}

*Append together datasets with variables needed

clear
use `bf'
order caseid-v003 hhid id_w mv001-mv003 id_m weight_w weight_m polygny age* educ* child* ideal* diff* work* d1 d2 d3 d4 index*
keep caseid-v003 hhid id_w mv001-mv003 id_m weight_w weight_m polygny age* educ* child* ideal* diff* work* d1 d2 d3 d4 index*
save `bf' ,replace

clear
use `et'
order caseid-v003 hhid id_w mv001-mv003 id_m weight_w weight_m polygny age* educ* child* ideal* diff* work* d1 d2 d3 d4 index*
keep caseid-v003 hhid id_w mv001-mv003 id_m weight_w weight_m polygny age* educ* child* ideal* diff* work* d1 d2 d3 d4 index*
append using `bf'

gen country = "Ethiopia" if v000 == "ET6"
replace country = "Burkina Faso" if v000 == "BF6"
save ../cleandata/dhs_microdata.dta, replace 
