set more off
clear all
/* ---------------------------------------------------------------------------

PURPOSE: Create Figures 1 and 2 in main text

DATE CREATED: 1/5/2018
--------------------------------------------------------------------------- */

**********************************************************************************
* Figure 1: Married women's and married men's desired fertility across countries *
**********************************************************************************
use ../cleandata/dhs.dta,clear

*Scatterplot of ideal number of children for men and women by country & above/below median polygny
count if idealnumchild_m_married!=. & idealnumchild_w_married!=.

gen countrylab = ""
replace countrylab = "Chad" if country=="Chad"
replace countrylab = "Niger" if country=="Niger"
replace countrylab = "Senegal" if country=="Senegal"
replace countrylab = "Gambia" if country=="Gambia"
twoway scatter idealnumchild_m_married idealnumchild_w_married, mlabel(countrylab) mlabpos(2) ///
	|| function y = x, range(0 10)  legend(off) graphregion(color(white)) ///
	ytitle("Men's Desired Fertility") xtitle("Women's Desired Fertility") 
graph export  ../outfigs/fig1.pdf, replace


*********************************************************************************
* Figure 2: Kernel density plots of the difference in ideal number of children  *
* between the husband and wife for women age 45 and older by country            *
*********************************************************************************
use ../cleandata/dhs_microdata.dta, clear

sum diffideal [aw=weight_w] if age_w>=45 & country=="Burkina Faso"
local bf = `r(mean)'
sum diffideal [aw=weight_w] if age_w>=45 & country=="Ethiopia"
local et = `r(mean)'
twoway (kdensity diffideal [aw=weight_w] if age_w>=45 & country=="Burkina Faso" , range(-10 10) bw(3) clcolor(black))  ///
	(kdensity diffideal [aw=weight_w] if age_w>=45 & country=="Ethiopia" , range(-10 10) bw(3) clcolor(black) clpattern(dash)) , ///
	xline(`bf', lcolor(black)) xline(`et', lpattern(dash) lcolor(black)) ///
	legend(order(1 "Burkina Faso" 2 "Ethiopia") rows(1)) ///
	xtitle("Difference in ideal number of children") ytitle("Density") graphregion(color(white)) 
graph export ../outfigs/fig2.pdf, replace

